import { __decorate, __classPrivateFieldSet, __classPrivateFieldGet } from 'tslib';
import { Memoized } from '@compositive/commons-memoize';
import { isColorHSL, isColorRGB, Style } from '@compositive/primitives';
import chroma from 'chroma-js';
import '../styling/resolveThemedStyleProperties.js';
import '../styling/ThemedStyle.js';
import 'react';

var _Color_chroma;
class Color {
    constructor(colorValue) {
        _Color_chroma.set(this, void 0);
        if ((colorValue === null || colorValue === void 0 ? void 0 : colorValue.constructor) === Color)
            return colorValue;
        if (colorValue instanceof Color) {
            __classPrivateFieldSet(this, _Color_chroma, chroma(colorValue.hex), "f");
            // @ts-expect-error: TODO: Need to dump Chroma
        }
        else if (colorValue instanceof chroma.Color) {
            // @ts-expect-error: TODO: Need to dump Chroma
            __classPrivateFieldSet(this, _Color_chroma, colorValue, "f");
        }
        else if (typeof colorValue === "string" ||
            typeof colorValue === "number") {
            __classPrivateFieldSet(this, _Color_chroma, chroma(colorValue), "f");
        }
        else if (isColorHSL(colorValue)) {
            const { h, s, l, a } = colorValue;
            __classPrivateFieldSet(this, _Color_chroma, chroma(h, s, l, "hsl").alpha(a !== null && a !== void 0 ? a : 1), "f");
        }
        else if (isColorRGB(colorValue)) {
            const { r, g, b, a } = colorValue;
            __classPrivateFieldSet(this, _Color_chroma, chroma(r, g, b, "rgb").alpha(a !== null && a !== void 0 ? a : 1), "f");
        }
        else {
            throw new TypeError(`Invalid color value: ${colorValue}`);
        }
    }
    static async fromJson(json) {
        return new Color(json);
    }
    static fromBinary([r, g, b]) {
        return new Color({ r, g, b });
    }
    static isValid(color) {
        return color instanceof Color || chroma.valid(color);
    }
    asForeground() {
        return new Style({ color: this });
    }
    asBackground() {
        return new Style({ backgroundColor: this });
    }
    toStaticStyle() {
        return this.asForeground();
    }
    get hex() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").hex();
    }
    get r() {
        return this.rgb[0];
    }
    get g() {
        return this.rgb[1];
    }
    get b() {
        return this.rgb[2];
    }
    get h() {
        return this.hsl[0];
    }
    get s() {
        return this.hsl[1];
    }
    get l() {
        return this.hsl[2];
    }
    get a() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").alpha();
    }
    get rgb() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").rgb();
    }
    get hsl() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").hsl();
    }
    get luminance() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").luminance();
    }
    alpha(alpha) {
        return new Color(__classPrivateFieldGet(this, _Color_chroma, "f").alpha(alpha));
    }
    toString() {
        return this.hex;
    }
    toBinary() {
        return new Uint8Array([this.r, this.g, this.b]);
    }
    async toJson() {
        return __classPrivateFieldGet(this, _Color_chroma, "f").css();
    }
}
_Color_chroma = new WeakMap();
__decorate([
    Memoized()
], Color.prototype, "asForeground", null);
__decorate([
    Memoized()
], Color.prototype, "asBackground", null);

export { Color };
//# sourceMappingURL=Color.js.map
