import { jsx } from 'react/jsx-runtime';
import { compactObject } from '@compositive/commons-util';
import { createContext, useContext } from 'react';
import '../theming/ComputedTheme.js';
import '../theming/Theme.js';
import '@compositive/commons-predicates';
import '../theming/ThemeContext.js';
import '@compositive/primitives';
import '../styling/resolveThemedStyleProperties.js';
import '../styling/ThemedStyle.js';
import { useTheme } from '../theming/useTheme.js';
import { Shade } from './Shade.js';

const DEFAULT_PROPS = {
    foreground: "foreground",
    background: "background",
    palette: "neutral",
};
const ColorContext = createContext(DEFAULT_PROPS);
const ColorProvider = (props) => {
    const previousInput = useContext(ColorContext);
    const { foreground, background, palette, children } = {
        ...previousInput,
        ...compactObject(props),
    };
    return (jsx(ColorContext.Provider, { value: { foreground, background, palette }, children: children }));
};
const ColorConsumer = ({ children, }) => {
    const values = useCurrentColors();
    return children(values);
};
const resolveShade = (theme, palette, pick, background) => {
    if (pick instanceof Shade) {
        return pick;
    }
    if (typeof pick === "string") {
        return resolveShade(theme, palette, theme.colorPicks[pick], background);
    }
    return pick.pickColor(palette, background);
};
const useCurrentColors = () => {
    const refs = useContext(ColorContext);
    const theme = useTheme();
    const palette = theme.palette[refs.palette];
    const background = resolveShade(theme, palette, refs.background);
    const foreground = resolveShade(theme, palette, refs.foreground, background);
    return { palette, background, foreground };
};
const useCurrentForeground = () => useCurrentColors().foreground;
const useCurrentBackground = () => useCurrentColors().background;
const useCurrentPalette = () => useCurrentColors().palette;

export { ColorConsumer, ColorProvider, useCurrentBackground, useCurrentForeground, useCurrentPalette };
//# sourceMappingURL=ColorContext.js.map
