import { Equals } from "@compositive/commons-predicates";
import type { Indexed } from "@compositive/commons-sequences";
import { Sequence } from "@compositive/commons-sequences";
import type { SerializableTo } from "@compositive/commons-serialization";
import type { HKT } from "@compositive/commons-types";
import type { ColorLikeValue } from "./Color";
import { Shade } from "./Shade";
export declare namespace ColorScale {
    type OutOfBoundsMethod = "none" | "wrap" | "clamp";
}
export declare namespace ColorScale {
    interface Type extends HKT {
        readonly type: FixedColorScale;
    }
}
export declare abstract class ColorScale extends Sequence<Shade> implements Indexed<number, Shade | undefined>, HKT.Holder {
    hktForSameElementKind: ColorScale.Type;
    constructor();
    get(key: number, OutOfBoundsMethod?: "none"): Shade | undefined;
    get(key: number, OutOfBoundsMethod: "wrap" | "clamp"): Shade;
    get(key: number, outOfBoundsMethod: ColorScale.OutOfBoundsMethod): Shade | undefined;
    has(key: number): boolean;
    get length(): number;
    get backmost(): Shade;
    get midpoint(): Shade;
    get frontmost(): Shade;
    filter(cb: (value: Shade, iteration: number) => boolean): ColorScale;
    [Equals](other: unknown): boolean;
    abstract get shades(): Shade[];
    abstract reversed(): ColorScale;
    protected buildNextWithSameElementKind<H extends HKT | HKT.Holder>(source: Iterable<Shade> | (() => Iterator<Shade, any, undefined>)): HKT.Kind<H, [Shade]>;
}
declare type SerializationFormat = Array<string>;
export declare class FixedColorScale extends ColorScale implements SerializableTo<SerializationFormat> {
    static fromJson(json: SerializationFormat): Promise<FixedColorScale>;
    readonly shades: Array<Shade>;
    constructor(colors: Iterable<ColorLikeValue> | (() => Iterator<ColorLikeValue, any, undefined>));
    reversed(): FixedColorScale;
    toJson(): Promise<SerializationFormat>;
}
export {};
//# sourceMappingURL=ColorScale.d.ts.map