import { __decorate } from 'tslib';
import { Memoized } from '@compositive/commons-memoize';
import { isOptional, isNumber, isInstanceOf } from '@compositive/commons-predicates';
import { Spec } from '@compositive/commons-spec';
import '../../color/Color.js';
import '../../color/ColorContext.js';
import '../../color/colors.js';
import '@compositive/commons-sequences';
import { Shade } from '../../color/Shade.js';
import '../../color/contrast/getCIECAM02Contrast.js';
import 'chroma-js';
import '../../color/contrast/types.js';
import '../../color/UniformLightnessColorScale.js';
import '../../theming/ComputedTheme.js';
import '../../theming/Theme.js';
import 'react/jsx-runtime';
import '../../theming/ThemeContext.js';
import { Style } from '@compositive/primitives';
import 'react';
import '../../styling/resolveThemedStyleProperties.js';
import '../../styling/ThemedStyle.js';

class SolidBorder extends Spec({
    width: isOptional(isNumber),
    shade: isInstanceOf(Shade),
}) {
    constructor() {
        super(...arguments);
        this.type = "border";
    }
    process(parts, chain) {
        return [parts.addInnerStyles(this._getStyle()), chain];
    }
    _getStyle() {
        var _a;
        return new Style({
            borderWidth: (_a = this.width) !== null && _a !== void 0 ? _a : 1,
            borderColor: this.shade,
        });
    }
}
__decorate([
    Memoized()
], SolidBorder.prototype, "_getStyle", null);

export { SolidBorder };
//# sourceMappingURL=SolidBorder.js.map
