import { Equals } from "@compositive/commons-predicates";
import type { Evaluator } from "@compositive/commons-spec";
import { ChainEvaluator } from "@compositive/commons-spec";
import type { Merge, NullablePartial } from "@compositive/commons-types";
import { Theme } from "./Theme";
/**
 * A {@link ComputedTheme} is a {@link Theme} implementation that allows for its values to be derived through the use of
 * pure functions and derivation rules.
 *
 * It's possible to create new themes from scratch, or through the extension of other themes,
 * by overriding only some of the values.
 */
export declare class ComputedTheme<A extends Theme.Attributes, V extends Theme.Variants> extends Theme<A, V> {
    #private;
    static with<D extends ComputedTheme.FullAttributeDefinition>(definition: D): ComputedTheme.InitiallyDefinedBy<D>;
    private constructor();
    using(activeVariants: NullablePartial<V>): Theme<A, V>;
    with<D extends ComputedTheme.OpenPartialAttributeDefinition<A>>(definition: D): ComputedTheme.WithExtraDefinition<A, D>;
    when<N extends string, K extends string>(variantName: N, options: Readonly<Record<K, ComputedTheme.ClosedPartialAttributeDefinition<A>>>): ComputedTheme.WithExtraVariant<A, V, N, K>;
    get surfaces(): A["surfaces"];
    get typography(): A["typography"];
    get metrics(): A["metrics"];
    get palette(): A["palette"];
    get colorPicks(): A["colorPicks"];
    get variants(): Theme.VariantOptions<V>;
    [Equals](other: unknown): boolean;
}
export declare type AnyComputedTheme = ComputedTheme<Theme.Open<Theme.Attributes>, Theme.Variants>;
export declare type UnknownComputedTheme = ComputedTheme<Theme.Attributes, Theme.NoVariants>;
export declare namespace ComputedTheme {
    type InitiallyDefinedBy<D extends OpenAttributeDefinition<any>> = WithExtraDefinition<Theme.Attributes, D>;
    type WithExtraDefinition<A extends Theme.Attributes, D extends OpenPartialAttributeDefinition<any>> = ComputedTheme<AttributesWithExtraDefinitions<A, D>, Theme.NoVariants>;
    type WithExtraVariant<A extends Theme.Attributes, V extends Theme.Variants, N extends string, K extends string> = ComputedTheme<A, Merge<V, {
        readonly [I in N]: K;
    }>>;
    type OpenPartialAttributes = {
        readonly [K in keyof Theme.Attributes & string]?: {
            readonly [x: string]: Theme.Attributes[K][keyof Theme.Attributes[K]] | undefined;
        };
    };
    type ClosedPartialAttributes<A extends Theme.Attributes> = {
        readonly [K in keyof A & string]?: {
            readonly [J in keyof A[K] & string]?: A[K][J];
        };
    };
    type FullAttributeDefinition = OpenAttributeDefinition<{}>;
    type OpenPartialAttributeDefinition<P extends Theme.Attributes> = Evaluator.AttributeDefinition<1, OpenPartialAttributes, P, Theme.Open<P>>;
    type ClosedPartialAttributeDefinition<P extends Theme.Attributes> = ChainEvaluator.PartialAttributeDefinition<1, P, P>;
    type OpenAttributeDefinition<P extends Evaluator.AttributeTypeRecord<1>> = Evaluator.AttributeDefinition<1, Theme.Open<Theme.Attributes>, P, Theme.Open<Theme.Attributes>>;
    type DefinedKeys<D extends Evaluator.AttributeTypeRecord<1>> = {
        [I in keyof D]: keyof D[I] & string;
    };
    type AttributesWithExtraDefinitions<A extends Theme.Attributes, D extends Evaluator.AttributeTypeRecord<1>> = Theme.AttributesWithExtraKeys<A, DefinedKeys<D>>;
}
//# sourceMappingURL=ComputedTheme.d.ts.map