import type { SerializableTo } from "@compositive/commons-serialization";
import type { AttributeDefinitions, AttributeValueDefinition } from "@compositive/commons-spec";
import type { ConvertibleToStyle } from "../styling";
import { StaticStyle } from "../styling";
import { FontDesignation } from "./FontDesignation";
import type { FontFamily } from "./FontFamily";
import type { FontLoader } from "./FontLoader";
import { FontStyle } from "./FontStyle";
import type { FontWeight } from "./FontWeight";
import { TextTransform } from "./TextTransform";
declare type SerializationFormat = {
    family: FontFamily;
    style: FontStyle;
    weight: FontWeight;
};
export declare class Font implements SerializableTo<SerializationFormat> {
    readonly family: FontFamily;
    readonly weight: FontWeight;
    readonly style: FontStyle;
    readonly fontLoader: FontLoader;
    constructor(family: FontFamily, weight: FontWeight, style: FontStyle, fontLoader: FontLoader);
    withSize(size: AttributeValueDefinition<FontSpec["attributes"], "size">): FontSpec;
    with(attributeName: "size", value: AttributeValueDefinition<FontSpec["attributes"], "size">): FontSpec;
    with(values: Omit<AttributeDefinitions<FontSpec["attributes"]>, "font">): FontSpec;
    get designation(): FontDesignation;
    get bolder(): Font;
    get lighter(): Font;
    get italic(): Font;
    get normal(): Font;
    load(): Promise<void>;
    isLoaded(): boolean;
    toString(): string;
    toJson(): Promise<SerializationFormat>;
}
declare const FontSpec_base: new (attributes: import("@compositive/commons-spec/AttributeDefiner").AttributeDefiner<import("@compositive/commons-predicates").InferRecordType<{
    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
}>> | AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
}>>, variants?: import("@compositive/commons-spec/VariantDefiner").VariantDefinitions<Record<never, string>> | import("@compositive/commons-spec/VariantDefiner").VariantDefiner<Record<never, string>> | undefined) => import("@compositive/commons-spec").AbstractSpec<import("@compositive/commons-predicates").InferRecordType<{
    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
}>, Record<never, string>> & {
    readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>>;
    readonly variants: Readonly<{}>;
    get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>[K];
    with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, K_1>): TSelf;
    with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>>>): TSelf_1;
    when<TSelf_2, K_2 extends string, O extends string>(this: TSelf_2, name: K_2, options: { [key in O]: (self: TSelf_2) => TSelf_2; }): TSelf_2 & {
        readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>>;
        readonly variants: Readonly<({ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never) extends infer T ? { [K_3 in keyof T]: ({ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never)[K_3][]; } : never>;
        get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>[K];
        with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, K_1>): TSelf;
        with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>>>): TSelf_1;
        when<TSelf_3, K_4 extends string, O_1 extends string>(this: TSelf_3, name: K_4, options: { [key_1 in O_1]: (self: TSelf_3) => TSelf_3; }): TSelf_3 & {
            readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>>;
            readonly variants: Readonly<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }> extends infer T_2 ? { [K_5 in keyof T_2]: import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>[K_5][]; } : never>;
            get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>[K];
            with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, K_1>): TSelf;
            with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>>>): TSelf_1;
            when<TSelf_4, K_6 extends string, O_2 extends string>(this: TSelf_4, name: K_6, options: { [key_2 in O_2]: (self: TSelf_4) => TSelf_4; }): TSelf_4 & {
                readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>>;
                readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }> extends infer T_3 ? { [K_7 in keyof T_3]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>[K_7][]; } : never>;
                get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>[K];
                with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, K_1>): TSelf;
                with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>>>): TSelf_1;
                when<TSelf_5, K_8 extends string, O_3 extends string>(this: TSelf_5, name: K_8, options: { [key_3 in O_3]: (self: TSelf_5) => TSelf_5; }): TSelf_5 & {
                    readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>>;
                    readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }> extends infer T_4 ? { [K_9 in keyof T_4]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>[K_9][]; } : never>;
                    get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>[K];
                    with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, K_1>): TSelf;
                    with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>>>): TSelf_1;
                    when<TSelf_6, K_10 extends string, O_4 extends string>(this: TSelf_6, name: K_10, options: { [key_4 in O_4]: (self: TSelf_6) => TSelf_6; }): TSelf_6 & {
                        readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>>;
                        readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }> extends infer T_5 ? { [K_11 in keyof T_5]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>[K_11][]; } : never>;
                        get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>[K];
                        with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, K_1>): TSelf;
                        with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>>>): TSelf_1;
                        when<TSelf_7, K_12 extends string, O_5 extends string>(this: TSelf_7, name: K_12, options: { [key_5 in O_5]: (self: TSelf_7) => TSelf_7; }): TSelf_7 & {
                            readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>>;
                            readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }> extends infer T_6 ? { [K_13 in keyof T_6]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>[K_13][]; } : never>;
                            get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>[K];
                            with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, K_1>): TSelf;
                            with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>>>): TSelf_1;
                            when<TSelf_8, K_14 extends string, O_6 extends string>(this: TSelf_8, name: K_14, options: { [key_6 in O_6]: (self: TSelf_8) => TSelf_8; }): TSelf_8 & {
                                readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>>;
                                readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }> extends infer T_7 ? { [K_15 in keyof T_7]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>[K_15][]; } : never>;
                                get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>[K];
                                with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, K_1>): TSelf;
                                with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>>>): TSelf_1;
                                when<TSelf_9, K_16 extends string, O_7 extends string>(this: TSelf_9, name: K_16, options: { [key_7 in O_7]: (self: TSelf_9) => TSelf_9; }): TSelf_9 & {
                                    readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>>;
                                    readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }> extends infer T_8 ? { [K_17 in keyof T_8]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>[K_17][]; } : never>;
                                    get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>[K];
                                    with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, K_1>): TSelf;
                                    with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>>>): TSelf_1;
                                    when<TSelf_10, K_18 extends string, O_8 extends string>(this: TSelf_10, name: K_18, options: { [key_8 in O_8]: (self: TSelf_10) => TSelf_10; }): TSelf_10 & {
                                        readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>>;
                                        readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }> extends infer T_9 ? { [K_19 in keyof T_9]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }>[K_19][]; } : never>;
                                        get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>[K];
                                        with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, K_1>): TSelf;
                                        with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>>>): TSelf_1;
                                        when<TSelf_11, K_20 extends string, O_9 extends string>(this: TSelf_11, name: K_20, options: { [key_9 in O_9]: (self: TSelf_11) => TSelf_11; }): TSelf_11 & {
                                            readonly attributes: Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>>;
                                            readonly variants: Readonly<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }>, { [keys_9 in K_20]: O_9; }> extends infer T_10 ? { [K_21 in keyof T_10]: import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }>, { [keys_9 in K_20]: O_9; }>[K_21][]; } : never>;
                                            get<K extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(key: K): import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>[K];
                                            with<TSelf, K_1 extends "lineHeight" | "letterSpacing" | "textTransform" | "font" | "size">(this: TSelf, key: K_1, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, K_1>): TSelf;
                                            with<TSelf_1>(this: TSelf_1, attributes: Partial<AttributeDefinitions<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>>>): TSelf_1;
                                            when<TSelf_12, K_22 extends string, O_10 extends string>(this: TSelf_12, name: K_22, options: { [key_10 in O_10]: (self: TSelf_12) => TSelf_12; }): TSelf_12 & any & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>> & {
                                                withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                                }>, "font">) => TSelf_13;
                                                withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                                }>, "size">) => TSelf_14;
                                                withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                                }>, "lineHeight">) => TSelf_15;
                                                withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                                }>, "letterSpacing">) => TSelf_16;
                                                withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                                }>, "textTransform">) => TSelf_17;
                                            };
                                            using<TSelf_18>(this: TSelf_18, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }>, { [keys_9 in K_20]: O_9; }>>): TSelf_18;
                                            hasVariant(variantName: string): boolean;
                                        } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>> & {
                                            withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, "font">) => TSelf_13;
                                            withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, "size">) => TSelf_14;
                                            withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, "lineHeight">) => TSelf_15;
                                            withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, "letterSpacing">) => TSelf_16;
                                            withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                            }>, "textTransform">) => TSelf_17;
                                        };
                                        using<TSelf_19>(this: TSelf_19, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>, { [keys_8 in K_18]: O_8; }>>): TSelf_19;
                                        hasVariant(variantName: string): boolean;
                                    } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>> & {
                                        withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, "font">) => TSelf_13;
                                        withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, "size">) => TSelf_14;
                                        withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, "lineHeight">) => TSelf_15;
                                        withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, "letterSpacing">) => TSelf_16;
                                        withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                        }>, "textTransform">) => TSelf_17;
                                    };
                                    using<TSelf_20>(this: TSelf_20, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>, { [keys_7 in K_16]: O_7; }>>): TSelf_20;
                                    hasVariant(variantName: string): boolean;
                                } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>> & {
                                    withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, "font">) => TSelf_13;
                                    withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, "size">) => TSelf_14;
                                    withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, "lineHeight">) => TSelf_15;
                                    withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, "letterSpacing">) => TSelf_16;
                                    withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                    }>, "textTransform">) => TSelf_17;
                                };
                                using<TSelf_21>(this: TSelf_21, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>, { [keys_6 in K_14]: O_6; }>>): TSelf_21;
                                hasVariant(variantName: string): boolean;
                            } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>> & {
                                withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, "font">) => TSelf_13;
                                withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, "size">) => TSelf_14;
                                withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, "lineHeight">) => TSelf_15;
                                withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, "letterSpacing">) => TSelf_16;
                                withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                                }>, "textTransform">) => TSelf_17;
                            };
                            using<TSelf_22>(this: TSelf_22, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>, { [keys_5 in K_12]: O_5; }>>): TSelf_22;
                            hasVariant(variantName: string): boolean;
                        } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>> & {
                            withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, "font">) => TSelf_13;
                            withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, "size">) => TSelf_14;
                            withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, "lineHeight">) => TSelf_15;
                            withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, "letterSpacing">) => TSelf_16;
                            withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                            }>, "textTransform">) => TSelf_17;
                        };
                        using<TSelf_23>(this: TSelf_23, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>, { [keys_4 in K_10]: O_4; }>>): TSelf_23;
                        hasVariant(variantName: string): boolean;
                    } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>> & {
                        withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, "font">) => TSelf_13;
                        withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, "size">) => TSelf_14;
                        withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, "lineHeight">) => TSelf_15;
                        withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, "letterSpacing">) => TSelf_16;
                        withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                        }>, "textTransform">) => TSelf_17;
                    };
                    using<TSelf_24>(this: TSelf_24, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>, { [keys_3 in K_8]: O_3; }>>): TSelf_24;
                    hasVariant(variantName: string): boolean;
                } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>> & {
                    withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, "font">) => TSelf_13;
                    withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, "size">) => TSelf_14;
                    withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, "lineHeight">) => TSelf_15;
                    withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, "letterSpacing">) => TSelf_16;
                    withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                    }>, "textTransform">) => TSelf_17;
                };
                using<TSelf_25>(this: TSelf_25, activeVariants: Partial<import("@compositive/commons-types").Merge<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>, { [keys_2 in K_6]: O_2; }>>): TSelf_25;
                hasVariant(variantName: string): boolean;
            } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>> & {
                withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, "font">) => TSelf_13;
                withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, "size">) => TSelf_14;
                withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, "lineHeight">) => TSelf_15;
                withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, "letterSpacing">) => TSelf_16;
                withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
                }>, "textTransform">) => TSelf_17;
            };
            using<TSelf_26>(this: TSelf_26, activeVariants: Partial<import("@compositive/commons-types").Merge<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never, { [keys_1 in K_4]: O_1; }>>): TSelf_26;
            hasVariant(variantName: string): boolean;
        } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>> & {
            withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, "font">) => TSelf_13;
            withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, "size">) => TSelf_14;
            withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, "lineHeight">) => TSelf_15;
            withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, "letterSpacing">) => TSelf_16;
            withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
                size: import("@compositive/commons-predicates").Predicate<number, unknown>;
                lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
                letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
                textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
            }>, "textTransform">) => TSelf_17;
        };
        using<TSelf_27>(this: TSelf_27, activeVariants: Partial<{ [keys in K_2]: O; } extends infer T_1 ? T_1 extends { [keys in K_2]: O; } ? T_1 extends Record<string, any> ? import("@compositive/commons-types").Merge.Records<Record<never, string>, T_1> : import("@compositive/commons-types").FirstDefined<T_1, Record<never, string>> : never : never>): TSelf_27;
        hasVariant(variantName: string): boolean;
    } & Readonly<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>> & {
        withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, "font">) => TSelf_13;
        withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, "size">) => TSelf_14;
        withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, "lineHeight">) => TSelf_15;
        withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, "letterSpacing">) => TSelf_16;
        withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
            size: import("@compositive/commons-predicates").Predicate<number, unknown>;
            lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
            letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
            textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
        }>, "textTransform">) => TSelf_17;
    };
    using<TSelf_28>(this: TSelf_28, activeVariants: Partial<Record<never, string>>): TSelf_28;
    hasVariant(variantName: string): boolean;
} & Readonly<import("@compositive/commons-predicates").InferRecordType<{
    size: import("@compositive/commons-predicates").Predicate<number, unknown>;
    lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
    letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
    textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
}>> & {
    withFont: <TSelf_13>(this: TSelf_13, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, "font">) => TSelf_13;
    withSize: <TSelf_14>(this: TSelf_14, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, "size">) => TSelf_14;
    withLineHeight: <TSelf_15>(this: TSelf_15, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, "lineHeight">) => TSelf_15;
    withLetterSpacing: <TSelf_16>(this: TSelf_16, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, "letterSpacing">) => TSelf_16;
    withTextTransform: <TSelf_17>(this: TSelf_17, value: AttributeValueDefinition<import("@compositive/commons-predicates").InferRecordType<{
        size: import("@compositive/commons-predicates").Predicate<number, unknown>;
        lineHeight: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        font: import("@compositive/commons-predicates").Predicate<Font, unknown>;
        letterSpacing: import("@compositive/commons-predicates").Predicate<number | undefined, unknown>;
        textTransform: import("@compositive/commons-predicates").Predicate<TextTransform | undefined, unknown>;
    }>, "textTransform">) => TSelf_17;
};
export declare class FontSpec extends FontSpec_base implements ConvertibleToStyle<never> {
    get allFonts(): Font[];
    toStaticStyle(): StaticStyle;
}
export {};
//# sourceMappingURL=Font.d.ts.map