import type { SerializableTo } from "@compositive/commons-serialization";
import { Font } from "./Font";
import type { FontCatalog } from "./FontCatalog";
import { FontDesignation } from "./FontDesignation";
import type { FontLoader } from "./FontLoader";
import type { FontStyle } from "./FontStyle";
import type { FontWeight } from "./FontWeight";
export declare enum FontType {
    Cursive = "cursive",
    Fantasy = "fantasy",
    Monospace = "monospace",
    SansSerif = "sans-serif",
    Serif = "serif"
}
declare type WithThinFont = {
    readonly Thin: Font;
};
declare type WithThinItalicFont = {
    readonly ThinItalic: Font;
};
declare type WithThinObliqueFont = {
    readonly ThinOblique: Font;
};
declare type WithExtraLightFont = {
    readonly ExtraLight: Font;
};
declare type WithExtraLightItalicFont = {
    readonly ExtraLightItalic: Font;
};
declare type WithExtraLightObliqueFont = {
    readonly ExtraLightOblique: Font;
};
declare type WithLightFont = {
    readonly Light: Font;
};
declare type WithLightItalicFont = {
    readonly LightItalic: Font;
};
declare type WithLightObliqueFont = {
    readonly LightOblique: Font;
};
declare type WithRegularFont = {
    readonly Regular: Font;
};
declare type WithRegularItalicFont = {
    readonly RegularItalic: Font;
};
declare type WithRegularObliqueFont = {
    readonly RegularOblique: Font;
};
declare type WithMediumFont = {
    readonly Medium: Font;
};
declare type WithMediumItalicFont = {
    readonly MediumItalic: Font;
};
declare type WithMediumObliqueFont = {
    readonly MediumOblique: Font;
};
declare type WithSemiBoldItalicFont = {
    readonly SemiBoldItalic: Font;
};
declare type WithSemiBoldFont = {
    readonly SemiBold: Font;
};
declare type WithSemiBoldObliqueFont = {
    readonly SemiBoldOblique: Font;
};
declare type WithBoldItalicFont = {
    readonly BoldItalic: Font;
};
declare type WithBoldFont = {
    readonly Bold: Font;
};
declare type WithBoldObliqueFont = {
    readonly BoldOblique: Font;
};
declare type WithExtraBoldItalicFont = {
    readonly ExtraBoldItalic: Font;
};
declare type WithExtraBoldFont = {
    readonly ExtraBold: Font;
};
declare type WithExtraBoldObliqueFont = {
    readonly ExtraBoldOblique: Font;
};
declare type WithBlackFont = {
    readonly Black: Font;
};
declare type WithBlackItalicFont = {
    readonly BlackItalic: Font;
};
declare type WithBlackObliqueFont = {
    readonly BlackOblique: Font;
};
export declare abstract class FontFamily implements SerializableTo<string> {
    #private;
    readonly name: string;
    readonly fallback: Array<FontFamily | string>;
    readonly fontType: FontType;
    constructor(name: string, fontType: FontType, fallback?: Array<FontFamily | string>);
    abstract get fontLoader(): FontLoader;
    abstract get fontCatalog(): FontCatalog<FontFamily>;
    withFont(w: FontWeight<"Thin">, s: FontStyle.Normal): this & WithThinFont;
    withFont(w: FontWeight<"Thin">, s: FontStyle.Italic): this & WithThinItalicFont;
    withFont(w: FontWeight<"Thin">, s: FontStyle.Oblique): this & WithThinObliqueFont;
    withFont(w: FontWeight<"ExtraLight">, s: FontStyle.Normal): this & WithExtraLightFont;
    withFont(w: FontWeight<"ExtraLight">, s: FontStyle.Italic): this & WithExtraLightItalicFont;
    withFont(w: FontWeight<"ExtraLight">, s: FontStyle.Oblique): this & WithExtraLightObliqueFont;
    withFont(w: FontWeight<"Light">, s: FontStyle.Normal): this & WithLightFont;
    withFont(w: FontWeight<"Light">, s: FontStyle.Italic): this & WithLightItalicFont;
    withFont(w: FontWeight<"Light">, s: FontStyle.Oblique): this & WithLightObliqueFont;
    withFont(w: FontWeight<"Regular">, s: FontStyle.Normal): this & WithRegularFont;
    withFont(w: FontWeight<"Regular">, s: FontStyle.Italic): this & WithRegularItalicFont;
    withFont(w: FontWeight<"Regular">, s: FontStyle.Oblique): this & WithRegularObliqueFont;
    withFont(w: FontWeight<"Medium">, s: FontStyle.Normal): this & WithMediumFont;
    withFont(w: FontWeight<"Medium">, s: FontStyle.Italic): this & WithMediumItalicFont;
    withFont(w: FontWeight<"Medium">, s: FontStyle.Oblique): this & WithMediumObliqueFont;
    withFont(w: FontWeight<"SemiBold">, s: FontStyle.Normal): this & WithSemiBoldFont;
    withFont(w: FontWeight<"SemiBold">, s: FontStyle.Italic): this & WithSemiBoldItalicFont;
    withFont(w: FontWeight<"SemiBold">, s: FontStyle.Oblique): this & WithSemiBoldObliqueFont;
    withFont(w: FontWeight<"Bold">, s: FontStyle.Normal): this & WithBoldFont;
    withFont(w: FontWeight<"Bold">, s: FontStyle.Italic): this & WithBoldItalicFont;
    withFont(w: FontWeight<"Bold">, s: FontStyle.Oblique): this & WithBoldObliqueFont;
    withFont(w: FontWeight<"ExtraBold">, s: FontStyle.Normal): this & WithExtraBoldFont;
    withFont(w: FontWeight<"ExtraBold">, s: FontStyle.Italic): this & WithExtraBoldItalicFont;
    withFont(w: FontWeight<"ExtraBold">, s: FontStyle.Oblique): this & WithExtraBoldObliqueFont;
    withFont(w: FontWeight<"Black">, s: FontStyle.Normal): this & WithBlackFont;
    withFont(w: FontWeight<"Black">, s: FontStyle.Italic): this & WithBlackItalicFont;
    withFont(w: FontWeight<"Black">, s: FontStyle.Oblique): this & WithBlackObliqueFont;
    /**
     * List of the fonts belonging to this family.
     */
    get fonts(): Readonly<Font[]>;
    get weights(): Readonly<FontWeight<any>[]>;
    get styles(): Readonly<FontStyle[]>;
    getFont(designation: FontDesignation): Font | undefined;
    getFont(weight: FontWeight, style: FontStyle): Font | undefined;
    getClosestFont(weight: FontWeight, style: FontStyle): Font | undefined;
    toString(): string;
    toJson(): Promise<string>;
}
export {};
//# sourceMappingURL=FontFamily.d.ts.map