import { __classPrivateFieldGet } from 'tslib';
import { isDefined } from '@compositive/commons-predicates';
import { Font } from './Font.js';
import { FontDesignation } from './FontDesignation.js';

var _FontFamily_fontMap;
var FontType;
(function (FontType) {
    FontType["Cursive"] = "cursive";
    FontType["Fantasy"] = "fantasy";
    FontType["Monospace"] = "monospace";
    FontType["SansSerif"] = "sans-serif";
    FontType["Serif"] = "serif";
})(FontType || (FontType = {}));
class FontFamily {
    constructor(name, fontType, fallback = []) {
        _FontFamily_fontMap.set(this, new Map());
        this.name = name;
        this.fontType = fontType;
        this.fallback = fallback;
    }
    withFont(weight, style) {
        const designation = FontDesignation.for(weight, style);
        const font = new Font(this, weight, style, this.fontLoader);
        __classPrivateFieldGet(this, _FontFamily_fontMap, "f").set(designation, font);
        Object.defineProperty(this, designation.toString(), { get: () => font });
        return this;
    }
    /**
     * List of the fonts belonging to this family.
     */
    get fonts() {
        return [...new Set(__classPrivateFieldGet(this, _FontFamily_fontMap, "f").values())];
    }
    get weights() {
        return [...new Set(this.fonts.map((font) => font.weight))];
    }
    get styles() {
        return [...new Set(this.fonts.map((font) => font.style))];
    }
    getFont(weightOrDesignation, style) {
        if (weightOrDesignation instanceof FontDesignation) {
            return __classPrivateFieldGet(this, _FontFamily_fontMap, "f").get(weightOrDesignation);
        }
        else {
            isDefined.assert(style);
            return __classPrivateFieldGet(this, _FontFamily_fontMap, "f").get(FontDesignation.for(weightOrDesignation, style));
        }
    }
    getClosestFont(weight, style) {
        const fallbacks = FontDesignation.for(weight, style).fallbacks;
        for (const fb of fallbacks) {
            if (__classPrivateFieldGet(this, _FontFamily_fontMap, "f").has(fb))
                return __classPrivateFieldGet(this, _FontFamily_fontMap, "f").get(fb);
        }
    }
    toString() {
        return [this.name, ...this.fallback, this.fontType]
            .map((t) => {
            const name = t instanceof FontFamily ? t.name : t;
            return name.includes(" ") ? `"${name}"` : name;
        })
            .join(", ");
    }
    async toJson() {
        return this.name;
    }
}
_FontFamily_fontMap = new WeakMap();

export { FontFamily, FontType };
//# sourceMappingURL=FontFamily.js.map
